/*
  File: OTAxisCell.h
  Authors: Matt Jacobus & Eric Bergerson
  Modification History:

  Created 10/01/90

  Copyright (c) 1990 Objective Technologies, Inc.
  All Rights Reserved.
*/

#import "OTGraphCell.h"

#define AXISCELL_CURRENT_VERSION 10

typedef struct _AC_Attributes {
  BOOL autoMajor;    /* determine # major ticks automatically */
  BOOL autoMinor;    /* determine # minor ticks automatically */
  BOOL autoSubminor; /* determine # subminor ticks automatically */
  int major; /* major ticks per rect */
  int minor; /* minor ticks per major tick */
  int subminor; /* subminor ticks per minor tick */
  double majorWidth;
  int  axisCellType;
} AC_Attributes;


@interface OTAxisCell: OTGraphCell
{
  AC_Attributes aCAttributes;
  double hashOffset;
  double hashInterSpacing;
}


+ initialize;
+ (AC_Attributes *) defaultAttributes;
- init;
- drawInside: (const NXRect *) cellFrame inView:controlView;
- drawAxis: (const NXRect *) cellFrame inView:controlView;
- drawTicks: (const  NXRect *) cellFrame inView:controlView;
- drawDefault: (const  NXRect *) cellFrame inView:controlView;
- updateTicks:(const NXRect *) cellFrame inView: controlView;
- (AC_Attributes *) aCAttributes;
- setACAttributes: (AC_Attributes *) anAttributes;
- (BOOL) isVertical;
- (BOOL) isHorizontal;
- (double) hashOffset;
- setHashOffset: (double) aHashOffset;
- (double) hashInterSpacing;
- setHashInterSpacing: (double) aHashInterSpacing;
- calcFrame: (NXRect *) cellFrame from: (const NXRect *) graphFrame;
- read: (NXTypedStream *) stream;
- write:(NXTypedStream *) stream;
- (BOOL) autoMajor;
- (BOOL) autoMinor;
- (BOOL) autoSubminor;
- setAutoMajor:(BOOL) newAutoMajor;
- setAutoMinor:(BOOL) newAutoMinor;
- setAutoSubminor:(BOOL) newAutoSubminor;
- setMajorTicks:(int) numTicks;
- setMinorTicks:(int) numTicks;
- setSubminorTicks:(int) numTicks;
- (int) majorTicks;
- (int) minorTicks;
- (int) subminorTicks;
- (int) axisCellType;
- setScaleIndex:(int) newIndex;
- (int) scaleIndex;

@end
