/*
  File: OTDataMngr.h
  Authors: Eric Bergerson
  Modification History:

  Created - 09/18/90

  Copyright (c) 1990 Objective Technologies, Inc.
  All Rights Reserved.
*/

#import <objc/List.h>
#import <appkit/graphics.h>

/* error messages */

#define DM_ERR_CANTOPENFILE 1

#define DATAMNGR_CURRENT_VERSION 13

typedef struct _DM_Extremes {
  NXPoint min;
  NXPoint max;
}DM_Extremes;

typedef struct _DM_Flags {
  BOOL extremesValid;
  BOOL autoValue;
  BOOL autoLabel;
  BOOL regularData;
}DM_Flags;

@interface OTDataMngr:List
{
  id xValues; /* nil, or a kind of Values */
  id xLabels; /* nil, or a kind of List containing String objects */

  id dataLabel;   /* String having name for entire data set */
  id rangeLabel;  /* String having name for set of range data */

  DM_Extremes dataLimits;
  DM_Flags dMFlags;

  BOOL dataChanged;
  BOOL rangeExtremesChanged;
  BOOL domainExtremesChanged;
  BOOL labelsChanged;

  id errorDelegate;
}



+ initialize;
- initCount: (unsigned) numSlots;
- initFromFile: (const char *) path;
- xValues;
- setXValues:anObject;
- xLabels;
- setXLabels:anObject;
- (DM_Extremes *) dataLimits;
- setDataLimits:(DM_Extremes *) newLimits;
- updateLimits;
- (BOOL) extremesAreValid;
- setExtremesValid: (BOOL) flag;
- (BOOL) isAutoValue;
- (BOOL) isAutoLabel;
- setAutoLabel: (BOOL) flag;
- (BOOL) isRegular;
- setRegularData: (BOOL) flag;
- (const DM_Flags *) dMFlags;
- setDMFlags: (const DM_Flags *) flagSet;
- dataLabel;
- setDataLabel:anObject;
- rangeLabel;
- setRangeLabel:anObject;
- (unsigned int) rangeCount;
- (unsigned int) domainCount;
- write:(NXTypedStream *) stream;
- read:(NXTypedStream *) stream;
- writeToFile: (const char *) path;
- createSubData;
- free;
- errorDelegate;
- setErrorDelegate: aDelegate;
- (BOOL) errorDidOccur: (int) errMsg from: aSelf;
- (BOOL) dataChanged;
- setDataChanged: (BOOL) flag;
- (BOOL) rangeExtremesChanged;
- setRangeExtremesChanged: (BOOL) flag;
- (BOOL) domainExtremesChanged;
- setDomainExtremesChanged: (BOOL) flag;
- (BOOL) labelsChanged;
- setLabelsChanged: (BOOL) flag;


@end

