/*
  File: OTGraph.h
  Authors: Matt Jacobus & Eric Bergerson
  Modification History:

  Created 10/11/90

  Copyright (c) 1990 Objective Technologies, Inc.
  All Rights Reserved.
*/

#import <appkit/Control.h>
#import "OTAxisCell.h"

/* Cell Frame and cells Positions */
#define G_GRAPH          0
#define G_LEFT           1
#define G_RIGHT          2
#define G_TOP            3
#define G_BOTTOM         4
#define G_MIDDLE_HOR     5
#define G_MIDDLE_VERT    6


#define G_CELLNUM        7
#define G_FIRSTAXISCELL  1
#define G_AXISCELLNUM    6
#define G_GRAPHCELLNUM   1

#define GRAPH_CURRENT_VERSION 10

@interface OTGraphBody: Control
{
  id oTScale;        /* a Scale object */
  id bodyCells;      /* List of six axisCells */
  id bodyCellFrames; /* Storage object containing six axisCell frames */
  id selectedCell;   /* The currently selected cell */
  id delegate;
  id errorDelegate;
  BOOL dirtyDisplay;
}



+ initialize;
- initFrame:(const NXRect *) frameRect;
+ setGraphCellClass:classId;
+ graphCellClass;
+ setAxisCellClass:classId;
+ (int)defaultAlignmentFor:(int) cellType;
+ setDefaultAlignmentFor:(int) cellType to:(int) anAlignment;
- free;
- drawSelf:(const NXRect *) rects :(int)rectCount;
- oTScale:(int) aScaleIndex;
- oTScale;
- setOTScale: anObject withChanged:(int) changed;
- bodyCellFrames;
- bodyCells;
- (unsigned int) count;
- delegate;
- setDelegate: anObject;
- stylizeCell: aCell type:(int) cellType;
- updateAxisTicks;
- updateFrames;
- cellAt: (int) cellType;
- setCell: aCell at:(int) cellType;
- (NXRect *) frameAt: (int) cellType;
- setFrame: (NXRect *) newFrame at: (int) cellType;
- mouseDown: (NXEvent *) anEvent;
- mouseEventDidOccur: sender;
- selectedCell;
- sizeToCells;
- graphWillDisplay: sender;
- graphDidDisplay: sender;
- newAxis:(int) cellType;
- freeCellAt:(int) cellType;
- setAxisMajorWidth:(double) aWidth;
- errorDelegate;
- setErrorDelegate: anObject;
- (BOOL) errorDidOccur: (int) errMsg from: aScale;
- read: (NXTypedStream *) stream;
- write:(NXTypedStream *) stream ;
- setTarget: anObject;
- setAction:(SEL) anAction;
- setDirtyDisplay:(BOOL) flag;
- (BOOL) dirtyDisplay;

@end
