/*
  File: OTScale.h
  Authors: Matt Jacobus & Eric Bergerson
  Modification History:

  Created 10/01/90

  Copyright (c) 1990 Objective Technologies, Inc.
  All Rights Reserved.
*/

#import <objc/Object.h>
#import <appkit/graphics.h>

/* error messages */
#define S_ERR_INVALIDTRANSFORM        0
#define S_ERR_NULLDATADIMENSION       1
#define S_ERR_NULLGRAPHDIMENSION      2
#define S_ERR_AUTOVALUENONREGULARDATA 3

/* defines for changed in setOTScale:withChanged: */
#define S_GRAPHSPACEONLY 0
#define S_DATASPACEONLY 1
#define S_BOTHSPACES 2

/* defines for attachStatus: */
#define S_ATTACHSTART 0
#define S_ATTACHENDSUCCESS 1
#define S_ATTACHENDFAILURE 2

#define SCALE_CURRENT_VERSION 10

@interface OTScale: Object
{
  id oTDataMngr;
  NXRect graphSpace;		/* representing pixels */
  NXRect dataSpace;             /* rect defining data space */
  NXSize dataSpaceStep;         /* size defining axis divisions
				   in data space */
  NXPoint scalingFactors;       /* graph points per data value */
  id errorDelegate;             /* recieves error messages */
  BOOL validTransform;          /* data space and graph space are def */
  BOOL autoRange;               /* use autoScaling on range data */
  BOOL autoDomain;              /* use autoScaling on domain data */
  BOOL regDataMargined;         /* Regular data contains margin */
  id subscales;                 /* List of secondary scales */
  id superscale;                /* Primary scale */
  id delegate;
  BOOL initialized;
}



+ initialize;
- init;
- (NXRect *) graphSpace;
- setGraphSpace: (NXRect *) aRect;
- oTDataMngr;
- setOTDataMngr: aDataMngr;
- errorDelegate;
- setErrorDelegate: aDelegate;
- convertPointFromGraph: (NXPoint *) aGraphPoint;
- convertPointFromData: (NXPoint *) aDataPoint;
- convertSizeFromGraph: (NXSize *) aGraphPoint;
- convertSizeFromData: (NXSize *) aDataPoint;
- convertRectFromGraph: (NXRect *) aGraphRect;
- convertRectFromData: (NXRect *) aDataRect;
- updateTransforms;
- updateDataSpace;
- (BOOL) isAutoDomain;
- (BOOL) isAutoRange;
- setAutoDomain:(BOOL) newAutoDomain;
- setAutoRange:(BOOL) newAutoRange;
- (const NXRect *) dataSpace;
- setDataSpace:(NXRect *) newDataSpace;
- (const NXSize *) dataSpaceStep;
- setDataSpaceStep: (NXSize *) newDataSpaceStep;
- read: (NXTypedStream *) stream;
- write:(NXTypedStream *) stream;
- (BOOL) validTransform;
- (BOOL) errorDidOccur: (int) errMsg from: aScale;
- (void) calcMajorTickMin:(double *) min max:(double *) max 
  step:(double *) step forRange:(BOOL) rangeData;
- (int) calcMajorTicksForRange:(BOOL) rangeData;
- (int) calcMinorTicksForRange:(BOOL) rangeData;
- (int) calcSubminorTicksForRange:(BOOL) rangeData;
- (BOOL) isRegDataMargined;
- setRegDataMargined:(BOOL)isMargined;
- createSubscale;
- freeSubscales;
- subscales;
- setSubscales:anObject;
- oTScale:(int) scaleIndex;
- superscale;
- setSuperscale: anObject;
- free;
- freeAllSubdata;
- (BOOL) hasSubscales;
- attachGraph:(NXPoint *) graphPoint to:(NXPoint *) dataPoint;
- attachData:(NXPoint *) dataPoint to:(NXPoint *) graphPoint;
- attachingStatus: (int) statusType from: sender;
- (double) distance: (NXPoint *)p1 :(NXPoint *) p2;
- setDelegate:anObject;
- delegate;
- scaleAfter: prevScale;
- (double) xValueAt:(int) dataIndex;
- (NXPoint *) scalingFactors;
- setScalingFactors: (NXPoint *) newFactors;
- (BOOL) mainScale;

@end


